#!/usr/bin/env python
# -*- coding: ISO-8859-1 -*-

#------------------
# ScummSpeaks
# Misc Classes and Functions
#------------------
# October 2008
#------------------

from shutil import copyfileobj

class SSException(Exception):
    pass

def determineSoundType(sHeader):
    if sHeader == "OggS":
        return "OGG"
    elif sHeader == 'fLaC':
        return "FLAC"
    # Dumb MP3 reading - note that we assume ID3v2 header is an MP3
    elif sHeader[:2] == '\xFF\xFB' or \
         sHeader == 'ID3\x03': # will scumm read this? it uses MAD so I assume so
        return "MP3"
    else:
        raise SSException("Unrecognized sound file type")

def copyFileContents(src, dst):
    copyfileobj(src, dst)

def strToNumber(string, reverse=False): # assumes LSB is first
    """ string = string to pass in, reverse = True for Big Endian"""
    # Could this be converted to use struct?
    #  No, because VOC block size is 3 bytes, and no C type is 3 bytes.
    
    # Pass 'True' as second argument for Big Endian conversion
    if reverse:
        string = reversed(string)
    size = 0
    for i, c in enumerate(string):
        size = size + (ord(c) << i*8)
    return size

def numToString(value, length, reverse=False):
    """ accepts any 'value', limited to 'length' characters. reverse = True for Big Endian"""
    lenrange = range(length)
    if reverse:
        lenrange = reversed(lenrange)
    string = ''
    for i in lenrange:
        string = string + chr((value >> i*8) % 0x100)
    return string
